summaryrefslogtreecommitdiffstats
path: root/khtml/html/html_tableimpl.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
commit560378aaca1784ba19806a0414a32b20c744de39 (patch)
treece0dfd7c3febf2a1adc7603d1019a8be2083c415 /khtml/html/html_tableimpl.h
parentd4d5af1cdbd3cc65d095e0afc5b1f4260091cf5d (diff)
downloadtdelibs-560378aaca1784ba19806a0414a32b20c744de39.tar.gz
tdelibs-560378aaca1784ba19806a0414a32b20c744de39.zip
Automated conversion for enhanced compatibility with TQt for Qt4 3.4.0 TP1
NOTE: This will not compile with Qt4 (yet), however it does compile with Qt3 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1211081 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'khtml/html/html_tableimpl.h')
-rw-r--r--khtml/html/html_tableimpl.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/khtml/html/html_tableimpl.h b/khtml/html/html_tableimpl.h
index 76d81ce50..277d76d14 100644
--- a/khtml/html/html_tableimpl.h
+++ b/khtml/html/html_tableimpl.h
@@ -277,7 +277,7 @@ public:
// overrides
virtual NodeImpl *addChild(NodeImpl *child);
virtual NodeImpl *insertBefore ( NodeImpl *newChild, NodeImpl *refChild, int &exceptioncode );
- virtual void replaceChild ( NodeImpl *newChild, NodeImpl *oldChild, int &exceptioncode );
+ virtual void tqreplaceChild ( NodeImpl *newChild, NodeImpl *oldChild, int &exceptioncode );
virtual void removeChild ( NodeImpl *oldChild, int &exceptioncode );
virtual NodeImpl *appendChild ( NodeImpl *newChild, int &exceptioncode );
@@ -285,7 +285,7 @@ public:
virtual void attach();
virtual void close();
/* Tries to find the section containing row number outIndex.
Returns whether it succeeded or not. negative outIndex values
are interpreted as being infinite.
@@ -295,7 +295,7 @@ public:
On failure, outSection points to the last section of the table, and
index is the offset the row would have if there was an additional section.
*/
- bool findRowSection(long inIndex,
+ bool tqfindRowSection(long inIndex,
HTMLTableSectionElementImpl*& outSection,
long& outIndex) const;
protected:
@@ -285,7 +285,7 @@ public:
virtual void attach();
virtual void close();
- /* Tries to find the section containing row number outIndex.
+ /* Tries to tqfind the section containing row number outIndex.
Returns whether it succeeded or not. negative outIndex values
are interpreted as being infinite.